###############################################################################
# Name: __init__.py                                                           #
# Purpose: initialize the syntax package                                      #
# Author: Cody Precord <cprecord@editra.org>                                  #
# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
# License: wxWindows License                                                  #
###############################################################################
"""Syntax data package

Provides:
  - Keyword Data
  - Syntax styling definitions

For all differn't file types and languages supported by Editra

"""
__author__ = "Cody Precord <cprecord@editra.org>"
__svnid__ = "$Id: __init__.py 52855 2008-03-27 14:53:06Z CJP $"
__revision__ = "$Revision: 52855 $"
